@@ -11,18 +11,18 @@
 # SPDX-License-Identifier: GPL-3.0
 
 esyd() {
-    local cmd="${1}"
+    cmd="${1}"
 
     shift
     case "${cmd}" in
     api)
-        echo -n 3
+        printf '%d' 3
         ;;
     check)
         test -c /dev/syd
         ;;
     panic|reset|stat)
-        [ -c /dev/syd/${cmd} ]
+        [ -c /dev/syd/"${cmd}" ]
         ;;
     load)
         if [ ${#} -ne 1 ]; then
@@ -42,41 +42,17 @@ esyd() {
         ;;
     info)
         if [ -c /dev/syd ]; then
-            if command -v jq >/dev/null 2>&1; then
-                local out
-                out=$(mktemp)
-                if [ -n "$BASH_VERSION" ]; then
-                    # We're in Bash
-                    # This works with lock:exec
-                    IFS=$'\n' readarray -t syd < /dev/syd
-                    echo "${syd[*]}" > "${out}"
-                elif [ -n "$ZSH_VERSION" ]; then
-                    syd=$(</dev/syd)
-                    echo "${syd}" > "${out}"
-                else
-                    # Fallback for POSIX sh
-                    # This needs lock:off, doesn't work with lock:exec
-                    cat /dev/syd > "${out}"
-                fi
+            # Note we cannot spawn a subshell here,
+            # while reading from `/dev/syd` otherwise
+            # this will break with lock:exec.
+            while IFS= read -r dat || [ -n "${dat}" ]; do
+                syd="${syd}${dat}"
+            done </dev/syd
 
-                jq "${@}" < "${out}"
-                r=$?
-                rm -f "${out}"
-                return $r
+            if command -v jq >/dev/null 2>&1; then
+                printf '%s' "${syd}" | jq "${@}"
             else
-                if [ -n "$BASH_VERSION" ]; then
-                    # We're in Bash
-                    # This works with lock:exec
-                    IFS=$'\n' readarray -t syd < /dev/syd
-                    echo "${syd[*]}"
-                elif [ -n "$ZSH_VERSION" ]; then
-                    syd=$(</dev/syd)
-                    echo "${syd}"
-                else
-                    # Fallback for POSIX sh
-                    # This needs lock:off, doesn't work with lock:exec
-                    cat /dev/syd
-                fi
+                printf '%s' "${syd}"
             fi
         else
             return 1
@@ -132,7 +108,7 @@ esyd() {
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
-        [ -c "$(syd-exec ${@})" ]
+        [ -c "$(syd-exec "${@}")" ]
         ;;
     force)
         if [ ${#} -ne 3 ]; then
@@ -404,8 +380,8 @@ esyd() {
         done
         ;;
     disallow|disallow_path)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -426,8 +402,8 @@ esyd() {
         done
         ;;
     nodeny|nodeny_path)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -445,8 +421,8 @@ esyd() {
         _esyd_path 'allow/stat' '+' "${@}"
         ;;
     disallow_stat)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -461,8 +437,8 @@ esyd() {
         _esyd_path 'deny/stat' '+' "${@}"
         ;;
     nodeny_stat)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -477,8 +453,8 @@ esyd() {
         _esyd_path 'allow/read' '+' "${@}"
         ;;
     disallow_read)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -493,8 +469,8 @@ esyd() {
         _esyd_path 'deny/read' '+' "${@}"
         ;;
     nodeny_read)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -509,8 +485,8 @@ esyd() {
         _esyd_path 'allow/write' '+' "${@}"
         ;;
     disallow_write)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -525,8 +501,8 @@ esyd() {
         _esyd_path 'deny/write' '+' "${@}"
         ;;
     nodeny_write)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -541,8 +517,8 @@ esyd() {
         _esyd_path 'allow/exec' '+' "${@}"
         ;;
     disallow_exec)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -557,8 +533,8 @@ esyd() {
         _esyd_path 'deny/exec' '+' "${@}"
         ;;
     nodeny_exec)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -573,8 +549,8 @@ esyd() {
         _esyd_path 'allow/ioctl' '+' "${@}"
         ;;
     disallow_ioctl)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -589,8 +565,8 @@ esyd() {
         _esyd_path 'deny/ioctl' '+' "${@}"
         ;;
     nodeny_ioctl)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -605,8 +581,8 @@ esyd() {
         _esyd_path 'allow/create' '+' "${@}"
         ;;
     disallow_create)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -621,8 +597,8 @@ esyd() {
         _esyd_path 'deny/create' '+' "${@}"
         ;;
     nodeny_create)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -637,8 +613,8 @@ esyd() {
         _esyd_path 'allow/delete' '+' "${@}"
         ;;
     disallow_delete)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -653,8 +629,8 @@ esyd() {
         _esyd_path 'deny/delete' '+' "${@}"
         ;;
     nodeny_delete)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -669,8 +645,8 @@ esyd() {
         _esyd_path 'allow/rename' '+' "${@}"
         ;;
     disallow_rename)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -685,8 +661,8 @@ esyd() {
         _esyd_path 'deny/rename' '+' "${@}"
         ;;
     nodeny_rename)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -701,8 +677,8 @@ esyd() {
         _esyd_path 'allow/symlink' '+' "${@}"
         ;;
     disallow_symlink)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -717,8 +693,8 @@ esyd() {
         _esyd_path 'deny/symlink' '+' "${@}"
         ;;
     nodeny_symlink)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -733,8 +709,8 @@ esyd() {
         _esyd_path 'allow/truncate' '+' "${@}"
         ;;
     disallow_truncate)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -749,8 +725,8 @@ esyd() {
         _esyd_path 'deny/truncate' '+' "${@}"
         ;;
     nodeny_truncate)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -765,8 +741,8 @@ esyd() {
         _esyd_path 'allow/chdir' '+' "${@}"
         ;;
     disallow_chdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -781,8 +757,8 @@ esyd() {
         _esyd_path 'deny/chdir' '+' "${@}"
         ;;
     nodeny_chdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -797,8 +773,8 @@ esyd() {
         _esyd_path 'allow/readdir' '+' "${@}"
         ;;
     disallow_readdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -813,8 +789,8 @@ esyd() {
         _esyd_path 'deny/readdir' '+' "${@}"
         ;;
     nodeny_readdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -829,8 +805,8 @@ esyd() {
         _esyd_path 'allow/mkdir' '+' "${@}"
         ;;
     disallow_mkdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -845,8 +821,8 @@ esyd() {
         _esyd_path 'deny/mkdir' '+' "${@}"
         ;;
     nodeny_mkdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -861,8 +837,8 @@ esyd() {
         _esyd_path 'allow/rmdir' '+' "${@}"
         ;;
     disallow_rmdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -877,8 +853,8 @@ esyd() {
         _esyd_path 'deny/rmdir' '+' "${@}"
         ;;
     nodeny_rmdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -893,8 +869,8 @@ esyd() {
         _esyd_path 'allow/chown' '+' "${@}"
         ;;
     disallow_chown)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -909,8 +885,8 @@ esyd() {
         _esyd_path 'deny/chown' '+' "${@}"
         ;;
     nodeny_chown)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -925,8 +901,8 @@ esyd() {
         _esyd_path 'allow/chgrp' '+' "${@}"
         ;;
     disallow_chgrp)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -941,8 +917,8 @@ esyd() {
         _esyd_path 'deny/chgrp' '+' "${@}"
         ;;
     nodeny_chgrp)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -957,8 +933,8 @@ esyd() {
         _esyd_path 'allow/chmod' '+' "${@}"
         ;;
     disallow_chmod)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -973,8 +949,8 @@ esyd() {
         _esyd_path 'deny/chmod' '+' "${@}"
         ;;
     nodeny_chmod)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -989,8 +965,8 @@ esyd() {
         _esyd_path 'allow/chattr' '+' "${@}"
         ;;
     disallow_chattr)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1005,8 +981,8 @@ esyd() {
         _esyd_path 'deny/chattr' '+' "${@}"
         ;;
     nodeny_chattr)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1021,8 +997,8 @@ esyd() {
         _esyd_path 'allow/chroot' '+' "${@}"
         ;;
     disallow_chroot)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1037,8 +1013,8 @@ esyd() {
         _esyd_path 'deny/chroot' '+' "${@}"
         ;;
     nodeny_chroot)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1053,8 +1029,8 @@ esyd() {
         _esyd_path 'allow/utime' '+' "${@}"
         ;;
     disallow_utime)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1069,8 +1045,8 @@ esyd() {
         _esyd_path 'deny/utime' '+' "${@}"
         ;;
     nodeny_utime)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1085,8 +1061,8 @@ esyd() {
         _esyd_path 'allow/mkdev' '+' "${@}"
         ;;
     disallow_mkdev)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1101,8 +1077,8 @@ esyd() {
         _esyd_path 'deny/mkdev' '+' "${@}"
         ;;
     nodeny_mkdev)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1117,8 +1093,8 @@ esyd() {
         _esyd_path 'allow/mkfifo' '+' "${@}"
         ;;
     disallow_mkfifo)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1133,8 +1109,8 @@ esyd() {
         _esyd_path 'deny/mkfifo' '+' "${@}"
         ;;
     nodeny_mkfifo)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1149,8 +1125,8 @@ esyd() {
         _esyd_path 'allow/mktemp' '+' "${@}"
         ;;
     disallow_mktemp)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1165,8 +1141,8 @@ esyd() {
         _esyd_path 'deny/mktemp' '+' "${@}"
         ;;
     nodeny_mktemp)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1174,9 +1150,9 @@ esyd() {
         _esyd_path 'deny/mktemp' "${op}" "${@}"
         ;;
     allow_net)
-        local op='-'
-        local c='allow/net/bind'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        c='allow/net/bind'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         case "${1}" in
         '--connect')
             c='allow/net/connect'
@@ -1192,9 +1168,9 @@ esyd() {
         _esyd_net "${c}" '+' "${@}"
         ;;
     disallow_net)
-        local op='-'
-        local c='allow/net/bind'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        c='allow/net/bind'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         case "${1}" in
         '--connect')
             c='allow/net/connect'
@@ -1210,9 +1186,9 @@ esyd() {
         _esyd_net "${c}" "${op}" "${@}"
         ;;
     deny_net)
-        local op='-'
-        local c='deny/net/bind'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        c='deny/net/bind'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         case "${1}" in
         '--connect')
             c='allow/net/connect'
@@ -1228,9 +1204,9 @@ esyd() {
         _esyd_net "${c}" '+' "${@}"
         ;;
     nodeny_net)
-        local op='-'
-        local c='deny/net/bind'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        c='deny/net/bind'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         case "${1}" in
         '--connect')
             c='allow/net/connect'
@@ -1255,8 +1231,8 @@ esyd() {
         done
         ;;
     rmfilter|rmfilter_path)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1273,8 +1249,8 @@ esyd() {
         _esyd_path 'filter/stat' '+' "${@}"
         ;;
     rmfilter_stat)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1289,8 +1265,8 @@ esyd() {
         _esyd_path 'filter/read' '+' "${@}"
         ;;
     rmfilter_read)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1305,8 +1281,8 @@ esyd() {
         _esyd_path 'filter/write' '+' "${@}"
         ;;
     rmfilter_write)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1321,8 +1297,8 @@ esyd() {
         _esyd_path 'filter/exec' '+' "${@}"
         ;;
     rmfilter_exec)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1337,8 +1313,8 @@ esyd() {
         _esyd_path 'filter/ioctl' '+' "${@}"
         ;;
     rmfilter_ioctl)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1353,8 +1329,8 @@ esyd() {
         _esyd_path 'filter/create' '+' "${@}"
         ;;
     rmfilter_create)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1369,8 +1345,8 @@ esyd() {
         _esyd_path 'filter/delete' '+' "${@}"
         ;;
     rmfilter_delete)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1385,8 +1361,8 @@ esyd() {
         _esyd_path 'filter/rename' '+' "${@}"
         ;;
     rmfilter_rename)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1401,8 +1377,8 @@ esyd() {
         _esyd_path 'filter/symlink' '+' "${@}"
         ;;
     rmfilter_symlink)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1417,8 +1393,8 @@ esyd() {
         _esyd_path 'filter/truncate' '+' "${@}"
         ;;
     rmfilter_truncate)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1433,8 +1409,8 @@ esyd() {
         _esyd_path 'filter/chdir' '+' "${@}"
         ;;
     rmfilter_chdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1449,8 +1425,8 @@ esyd() {
         _esyd_path 'filter/readdir' '+' "${@}"
         ;;
     rmfilter_readdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1465,8 +1441,8 @@ esyd() {
         _esyd_path 'filter/mkdir' '+' "${@}"
         ;;
     rmfilter_mkdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1481,8 +1457,8 @@ esyd() {
         _esyd_path 'filter/rmdir' '+' "${@}"
         ;;
     rmfilter_rmdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1497,8 +1473,8 @@ esyd() {
         _esyd_path 'filter/chown' '+' "${@}"
         ;;
     rmfilter_chown)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1513,8 +1489,8 @@ esyd() {
         _esyd_path 'filter/chgrp' '+' "${@}"
         ;;
     rmfilter_chgrp)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1529,8 +1505,8 @@ esyd() {
         _esyd_path 'filter/chmod' '+' "${@}"
         ;;
     rmfilter_chmod)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1545,8 +1521,8 @@ esyd() {
         _esyd_path 'filter/chattr' '+' "${@}"
         ;;
     rmfilter_chattr)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1561,8 +1537,8 @@ esyd() {
         _esyd_path 'filter/chroot' '+' "${@}"
         ;;
     rmfilter_chroot)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1577,8 +1553,8 @@ esyd() {
         _esyd_path 'filter/utime' '+' "${@}"
         ;;
     rmfilter_utime)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1593,8 +1569,8 @@ esyd() {
         _esyd_path 'filter/mkdev' '+' "${@}"
         ;;
     rmfilter_mkdev)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1609,8 +1585,8 @@ esyd() {
         _esyd_path 'filter/mkfifo' '+' "${@}"
         ;;
     rmfilter_mkfifo)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1625,8 +1601,8 @@ esyd() {
         _esyd_path 'filter/mktemp' '+' "${@}"
         ;;
     rmfilter_mktemp)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1641,8 +1617,8 @@ esyd() {
         _esyd_net 'filter/net' '+' "${@}"
         ;;
     rmfilter_net)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -2195,8 +2171,8 @@ EOF
 
 _esyd_path()
 {
-    local cmd="${1}"
-    local op="${2}"
+    cmd="${1}"
+    op="${2}"
 
     case "${op}" in
     '+'|'-')
@@ -2209,8 +2185,7 @@ _esyd_path()
 
     shift 2
 
-    local ret=0
-    local path
+    ret=0
     for path in "${@}"; do
         case "${path}" in
         /*)
@@ -2227,8 +2202,8 @@ _esyd_path()
 
 _esyd_net()
 {
-    local cmd="${1}"
-    local op="${2}"
+    cmd="${1}"
+    op="${2}"
 
     case "${op}" in
     '+'|'-')
@@ -2241,7 +2216,7 @@ _esyd_net()
 
     shift 2
 
-    local ret=0
+    ret=0
     while [ ${#} -gt 0 ] ; do
         # syd does input validation so we don't do any here.
         [ -c "/dev/syd/${cmd}${op}${1}" ] || ret=$?
